<?php

use PhpCsFixer\Fixer\FunctionNotation\FunctionTypehintSpaceFixer;
use PhpCsFixer\Fixer\FunctionNotation\MethodArgumentSpaceFixer;
use PhpCsFixer\Fixer\Import\OrderedImportsFixer;
use PhpCsFixer\Fixer\Operator\BinaryOperatorSpacesFixer;
use PhpCsFixer\Fixer\Operator\NotOperatorWithSuccessorSpaceFixer;
use Reinfi\EasyCodingStandard\JUnitOutputFormatter;
use Symplify\EasyCodingStandard\Config\ECSConfig;
use Symplify\EasyCodingStandard\ValueObject\Set\SetList;

return static function (ECSConfig $config): void
{
    $baseDir = dirname(__DIR__, 2);

    $config->paths([
        $baseDir . '/src',
    ]);

    $config->services()->set(JUnitOutputFormatter::class);

    $config->skip([
        $baseDir . '/dev-ops',
        $baseDir . '/vendor',
    ]);

    $config->lineEnding(PHP_EOL);

    $config->sets([
        SetList::PSR_12,
        SetList::NAMESPACES,
        SetList::SPACES,
        SetList::STRICT,
    ]);

    $config->ruleWithConfiguration(
        OrderedImportsFixer::class,
        [
            'imports_order' => [ 'const', 'class', 'function' ],
        ],
    );

    $config->ruleWithConfiguration(
        BinaryOperatorSpacesFixer::class,
        [
            'operators' => [
                '=>' => BinaryOperatorSpacesFixer::ALIGN,
                '='  => BinaryOperatorSpacesFixer::ALIGN,
            ],
        ],
    );

    $config->ruleWithConfiguration(
        MethodArgumentSpaceFixer::class,
        [
            'on_multiline' => 'ignore',
        ],
    );

    $config->skip([
        NotOperatorWithSuccessorSpaceFixer::class,
        FunctionTypehintSpaceFixer::class,
    ]);
};
