const path            = require('path');
const localesConfig   = require('./locales');
const composerJson    = require('../../../composer.json');
const locales         = {};
const sidebar         = {};

const stylesheetSource = 'production' === process.env.NODE_ENV
    ? 'https://cdn.io.netinventors.de/vue-press/css/manual.min.css'
    : '/manual.css';

const base = process.env.CI_PAGES_URL
    ? new URL(process.env.CI_PAGES_URL).pathname
    : '';

const extraWatchFiles = [
    path.resolve(__dirname, 'public/manual.css'),
];

localesConfig.forEach(locale => {
    const langPath = `/${locale.lang}/`;

    locales[langPath] = { lang: locale.locale };
    sidebar[langPath] = require(`./nav/${locale.lang}/sidebar`);

    extraWatchFiles.push(
        path.resolve(__dirname, 'nav', locale.lang, '*.js')
    );
});

const plugin = (() => {
    const name = composerJson.extra['shopware-plugin-class'].substring(
        composerJson.extra['shopware-plugin-class'].lastIndexOf('\\') + 1
    );

    const version = composerJson.version;

    return {
        name,
        version,
    };
})();

module.exports = {
    base: `${base}/`,
    locales,
    title: `${plugin.name}`,

    head: [
        [
            'link',
            {
                rel: 'preload',
                href: stylesheetSource,
                as: 'style'
            },
        ], [
            'link',
            {
                rel: 'stylesheet',
                href: stylesheetSource,
            },
        ],
    ],

    themeConfig: {
        logo: '/logo.svg',
        sidebar: 'auto',
        locales: sidebar,
    },

    plugins: [
        '@vuepress/active-header-links',
        [ '@vuepress/medium-zoom', { selector: 'main :not(a) > img' } ],
        [ '@vuepress/back-to-top', true ],
    ],

    markdown: {
        lineNumbers: true,
        plugins: [
            [ 'markdown-it-include' ],
        ],
    },

    patterns: [
        '**/!(inc.)*.md',
        '**/*.vue',
    ],

    extraWatchFiles: [
        ...extraWatchFiles
    ],

    configureWebpack: (config, isServer) => {},

    chainWebpack: (config, isServer) => {},
};
