<?php

declare(strict_types=1);

namespace NetInventors\NetiNextToolKit\Components;

use Doctrine\DBAL\Connection;
use NetInventors\NetiNextToolKit\Core\Content\PropertyGroup\Aggregate\Attribute\AttributeDefinition;
use NetInventors\NetiNextToolKit\Core\Content\PropertyGroupOption\Aggregate\OptionAttribute\OptionAttributeDefinition;
use NetInventors\NetiNextToolKit\Core\Content\PropertyGroupOption\Aggregate\OptionAttribute\Translation\OptionAttributeTranslationDefinition;
use Shopware\Core\Framework\Plugin\Context\InstallContext;
use Symfony\Component\DependencyInjection\ContainerInterface;

class Setup
{
    public function __construct(
        protected readonly InstallContext     $context,
        protected readonly ?ContainerInterface $container
    ) {
        if (!$container) {
            throw new \Exception('Service container not available');
        }
    }

    /**
     * @throws \Throwable
     */
    public function install(): void
    {
    }

    public function uninstall(): void
    {
        $this->deleteTables();
    }

    protected function deleteTables(): void
    {
        if (!$this->container) {
            return;
        }

        /** @var Connection $connection */
        $connection = $this->container->get(Connection::class);
        $connection->executeStatement('SET foreign_key_checks=0;');
        $connection->executeStatement('DROP TABLE IF EXISTS ' . AttributeDefinition::ENTITY_NAME);
        $connection->executeStatement('DROP TABLE IF EXISTS ' . OptionAttributeDefinition::ENTITY_NAME);
        $connection->executeStatement('DROP TABLE IF EXISTS ' . OptionAttributeTranslationDefinition::ENTITY_NAME);
        $connection->executeStatement('SET foreign_key_checks=1;');
    }
}
