<?php

declare(strict_types=1);

namespace NetInventors\NetiNextToolKit\Core\Content\PropertyGroup\Aggregate\Attribute;

use Shopware\Core\Content\Property\PropertyGroupDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\EntityDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\Field\BoolField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\FkField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\PrimaryKey;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\Required;
use Shopware\Core\Framework\DataAbstractionLayer\Field\IdField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\ManyToOneAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\FieldCollection;

/**
 * @psalm-suppress PropertyNotSetInConstructor
 */
class AttributeDefinition extends EntityDefinition
{
    final public const ENTITY_NAME = 'neti_tk_property_group_attribute';

    public function getEntityName(): string
    {
        return self::ENTITY_NAME;
    }

    public function getEntityClass(): string
    {
        return AttributeEntity::class;
    }

    public function getCollectionClass(): string
    {
        return AttributeCollection::class;
    }

    protected function defineFields(): FieldCollection
    {
        return new FieldCollection([
            (new IdField('id', 'id'))->addFlags(new Required(), new PrimaryKey()),

            (new FkField('property_group_id', 'propertyGroupId', PropertyGroupDefinition::class))->addFlags(new Required()),
            (new ManyToOneAssociationField('propertyGroup', 'property_group_id', PropertyGroupDefinition::class)),

            new BoolField('display_in_listing', 'displayInListing'),
        ]);
    }
}
