<?php

declare(strict_types=1);

namespace NetInventors\NetiNextToolKit\Decorator;

use Shopware\Core\Content\Product\SalesChannel\Search\AbstractProductSearchRoute;
use Shopware\Core\Content\Product\SalesChannel\Search\ProductSearchRouteResponse;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Criteria;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Filter\EqualsFilter;
use Shopware\Core\System\SalesChannel\SalesChannelContext;
use Symfony\Component\HttpFoundation\Request;

class ProductSearchRouteDecorator extends AbstractProductSearchRoute
{
    public function __construct(
        private readonly AbstractProductSearchRoute $mainService
    ) {
    }

    public function getDecorated(): AbstractProductSearchRoute
    {
        return $this->mainService;
    }

    public function load(
        Request             $request,
        SalesChannelContext $context,
        Criteria            $criteria
    ): ProductSearchRouteResponse {
        $criteria->addAssociation('properties.group');
        $criteria->getAssociation('properties')->addFilter(
            new EqualsFilter('group.netiToolKitAttribute.displayInListing', true)
        );

        return $this->mainService->load($request, $context, $criteria);
    }
}
