<?php

declare(strict_types=1);

namespace NetInventors\NetiNextToolKit\Serializer\Normalizer;

use NetInventors\NetiNextToolKit\Struct\PluginConfigStruct;
use Symfony\Component\Serializer\Exception\NotNormalizableValueException;
use Symfony\Component\Serializer\Exception\RuntimeException;
use Symfony\Component\Serializer\Normalizer\DenormalizerInterface;

class PluginConfigDenormalizer implements DenormalizerInterface
{
    public function denormalize($data, string $type, string $format = null, array $context = []): PluginConfigStruct
    {
        if (!is_array($data)) {
            throw new NotNormalizableValueException();
        }

        $denormalizedObject = new PluginConfigStruct();

        $closureFn = \Closure::bind(
            /** @psalm-suppress InaccessibleProperty */
            static function (PluginConfigStruct $denormalizedObject) use ($data): void {
                if (isset($data['active'])) {
                    $denormalizedObject->active = (bool) $data['active'];
                }
            },
            null,
            PluginConfigStruct::class,
        );

        if (!$closureFn) {
            throw new RuntimeException();
        }

        $closureFn($denormalizedObject);

        return $denormalizedObject;
    }

    public function supportsDenormalization($data, string $type, string $format = null): bool
    {
        return PluginConfigStruct::class === $type;
    }
}
